#!/bin/bash
#
# Source : http://etherape.sourceforge.net/download.shtml
#
# packager : gmg (gerard.monpontet~AT~wanadoo.fr).
#

soft='etherape'
softversion='0.9.9'
packageversion='66.1'

arch='i486'
cpu='i686'

# log
(

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://downloads.sourceforge.net/project/etherape/etherape/$softversion/$soft-$softversion.tar.gz

# check if source is present
if [ -f $soft-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.txz
rm -rf $dest
mkdir -p $dest

cd $src

chown -R root:root .
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure --prefix=/usr --sysconfdir=/etc

make DESTDIR=$dest
make install DESTDIR=$dest

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)
( mv $dest/usr/share/man $dest/usr/man
  cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# redundant

rm -rf $dest/usr/share/doc

# Desktop file
cat << "EOF" > $dest/usr/share/applications/etherape.desktop
[Desktop Entry]
Version=1.0
Encoding=UTF-8
Name=EtherApe
Comment=Graphical Network Monitor
Exec=gksu etherape
Terminal=false
Type=Application
Icon=etherape
Categories=Application;Network;
EOF

# Icons go to hicolor

mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mv $dest/usr/share/pixmaps/etherape.png $dest/usr/share/icons/hicolor/48x48/apps/
rm -rf $dest/usr/share/pixmaps

# Description file

mkdir -p $dest/install

cat << EOF > $dest/install/slack-desc
        |-----handy-ruler---------------------------------------------------|
$soft: etherape (graphical network monitor for unix)
$soft:
$soft: is a graphical network monitor for Unix modeled after
$soft: etherman.Featuring link layer, ip and TCP modes, it displays 
$soft: network activity graphically. Hosts and links change in size 
$soft: with traffic. Color coded protocols display.
$soft:
$soft:
$soft:
$soft:
EOF

cat << EoF > $dest/install/doinst.sh
# Update the scrollkeeper database (Remove stale pieces)
if [ -x usr/bin/scrollkeeper-update ]; then
	echo "Updating scrollkeeper database.. Give me a sec"
        usr/bin/scrollkeeper-update > /dev/null 2>&1
fi
EoF

# Documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  ABOUT-NLS AUTHORS ChangeLog COPYING FAQ INSTALL NEWS OVERVIEW README \
  README.bugs README.help README.thanks TODO \
  $dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion
chmod 755 $dest/usr/src/build-$soft.sh

# Packaging

cd $dest
makepkg -l y -c n $dest.txz
cd $buildir
md5sum $package.txz >$package.md5

# Erase source directory
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$soft-$softversion-build.log"
